@@ -2,7 +2,7 @@
     <one line to give the library's name and an idea of what it does.>
     Copyright (C) 2012-2013  Vishesh Handa <me@vhanda.in>
 
-    Adapated from KFileMetadataWidget
+    Adapted from KFileMetadataWidget
     Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>
     Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>
 
@@ -83,8 +83,8 @@ private:
 
 FileMetaDataWidget::Private::Private(FileMetaDataWidget* parent)
     : m_rows()
-    , m_provider(0)
-    , m_gridLayout(0)
+    , m_provider(nullptr)
+    , m_gridLayout(nullptr)
     , q(parent)
 {
     m_filter = new MetadataFilter(q);
@@ -128,7 +128,7 @@ void FileMetaDataWidget::Private::slotLoadingFinished()
 {
     deleteRows();
     
-    if (m_gridLayout == 0) {
+    if (m_gridLayout == nullptr) {
         m_gridLayout = new QGridLayout(q);
         m_gridLayout->setMargin(0);
         m_gridLayout->setSpacing(q->fontMetrics().height() / 4);
@@ -261,10 +261,19 @@ bool FileMetaDataWidget::isReadOnly() const
 {
     return d->m_provider->isReadOnly();
 }
+void FileMetaDataWidget::setDateFormat(const DateFormats format)
+{
+     d->m_widgetFactory->setDateFormat(format);
+}
+
+DateFormats FileMetaDataWidget::dateFormat() const
+{
+    return d->m_widgetFactory->dateFormat();
+}
 
 QSize FileMetaDataWidget::sizeHint() const
 {
-    if (d->m_gridLayout == 0) {
+    if (d->m_gridLayout == nullptr) {
         return QWidget::sizeHint();
     }
 
